#
# spec file for package waf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waf
Version:        2.1.2
Release:        1.3
Summary:        The Waf build system
License:        BSD-3-Clause
Group:          Development/Tools/Building
URL:            https://waf.io
Source0:        https://waf.io/%{name}-%{version}.tar.bz2
Source1:        https://waf.io/%{name}-%{version}.tar.bz2.asc
Source2:        waf.keyring
BuildRequires:  python3-base
BuildArch:      noarch

%description
Waf is a Python-based framework for configuring, compiling and installing applications.

%prep
%setup -q -n waf-%{version}
find ./waflib -iname \*py -print -exec sed -i -e '1{ s/#!.*/#!foo/ }' '{}' \;

%build
python3 ./waf-light configure build
# Unpack waflib
python3 -c "import zipfile; z = zipfile.ZipFile('./zip/waflib.zip'); z.extractall(path='./zip/')"

cat <<EOF > ./waf.wrapper
#!/usr/bin/python3
import os, sys;
cwd = os.getcwd()
wafdir = "%{_datadir}/waf/"
sys.path.insert(0, wafdir)

if __name__ == '__main__':
	from waflib import Scripting
	Scripting.waf_entry_point(cwd, "%{version}", wafdir)
EOF

%install
install -m 755 -D waf.wrapper %{buildroot}%{_bindir}/waf
install -m 755 -d %{buildroot}%{_datadir}/waf/
cp -pR ./zip/waflib %{buildroot}%{_datadir}/waf/
%python3_fix_shebang

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}/%{_datadir}/waf/
%{buildroot}/%{_bindir}/waf -h

%files
%doc README.md
%{_bindir}/waf
%{_datadir}/waf

%changelog
* Mon Oct  7 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.1.2:
  * Work around some Python regressions
  * Add latex dependeny on environment variables
  * Add support for flang compiler
* Mon Jul  1 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.1.1
  * Fixed some argparse regressions
  * Fixed 'waf --version'
  * Updated most project examples
- Update to 2.1.0
  * While the Waf file runs on Python 2 and 3, creating it requires Python 3
    + Added wafcache
    + waf_unit_test: Added task in returned tuples, custom reports should be adapted
    ~ Ensure ConfigurationContext.load and Context.load definitions are consistent
    and remove unused *k parameters
    ~ Remove the dependency on optparse and use argparse instead
- added public key and signature
* Fri Apr  5 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue Dec 19 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Do not write non-deterministic .pyc files in tests
* Mon Dec  4 2023 Wang Jun <badboywj@gmail.com>
- Update to 2.0.26
  * Improve "waf dist" - Support SOURCE_DATE_EPOCH
  * Detect Qt6 #2355
  * Haxe toolkit support #2352
  * Updated the project's gpg key
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.25:
  * Fix invalid characters returned by find_program #2397
  * Prepare for distutils removal (Python 3.12 regression) #2402
  * Improve cp65001 compat in cpython < 3.3 #2346
  * Add Fujitsu Fortran compiler detection on ARM64FX #2348
  * Support multiple Sphinx output formats #2344
  * Improve PyQt5 detection #2343
  * Add asynchronous wafcache uploads
* Mon Jun 27 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Initial package version (2.0.24)
